@@ -46,9 +46,4 @@ def draw(data, dataInputType='normal Array'):
     operationInstance.endDraw()
     # main()
 
-import json
-dataDict = {}
-f = open('./testFile.json', 'r')
-dataDict = json.loads(f.read())
-draw(dataDict)
 
